import os
import requests
import configparser

config = configparser.ConfigParser()
config.read("config.ini", encoding='utf-8')

proxies = {
    'https': config["main"]["PROXY"],
}
API_KEY = config["main"]["OPENAI_API_KEY"]
TEMPERATURE = int(config["main"]["temperature"])
MODEL = config["main"]["model"]
API_PROMPT = config["main"]["prompt"]

FOLDER_PATH = 'knowledge/'

def get_response(user_input, data):
    prompt = f"""
    {API_PROMPT}
    
    Данные: {data}
             
    Запрос: {user_input}
    """

    response = requests.post(
        "https://api.openai.com/v1/chat/completions",
        headers={
            "Content-Type": "application/json",
            "Authorization": "Bearer " + API_KEY
        },
        json={
            "model": MODEL,
            "messages": [{"role": "user", "content": prompt}],
            "temperature": TEMPERATURE,
            "max_tokens": 4095,
        }, 
        proxies=proxies
    ).json()

    if response.get("choices"):
        responseText = response["choices"][0]["message"]["content"]
    else:
        responseText = "No response from OpenAI."
    return responseText

def load_data_from_folder():
    data = ""
    for filename in os.listdir(FOLDER_PATH):
        with open(os.path.join(FOLDER_PATH, filename), 'r', encoding='utf-8') as file:
            data += file.read() + "\n"
    return data

def main():
    data = load_data_from_folder()
    while True:
        user_input = input("Вы: ")
        response = get_response(user_input, data)
        print(f"ChatGPT: {response}")

if __name__ == "__main__":
    main()